<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;
use Intuit\Jobs\AccountingCustomerUpdate;
use Intuit\Models\Customer as AccAccount;

use App\Models\{Account,ProviderOauth,Site,User};

class AccountingAccountAdd extends Command
{
	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'accounting:account:add'
		.' {siteid : Site ID}'
		.' {provider : Provider Name}'
		.' {user : User Email}'
		.' {id : Account ID}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Add an account to the accounting provider';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 */
	public function handle()
	{
		$site = Site::findOrFail($this->argument('siteid'));
		Config::set('site',$site);

		$uo = User::where('email',$this->argument('user'))->singleOrFail();

		$so = ProviderOauth::where('name',$this->argument('provider'))->singleOrFail();
		if (! ($to=$so->token($uo)))
			abort(500,sprintf('Unknown Tokens for [%s]',$uo->email));

		$o = Account::findOrFail($this->argument('id'));

		$acc = new AccAccount;
		$acc->PrimaryEmailAddr = (object)['Address'=>$o->user->email];
		$acc->ResaleNum = $o->sid;
		$acc->GivenName = $o->user->firstname;
		$acc->FamilyName = $o->user->lastname;
		$acc->CompanyName = $o->name;
		$acc->DisplayName = $o->name;
		$acc->FullyQualifiedName = $o->name;
		$acc->Active = (bool)$o->active;

		return AccountingCustomerUpdate::dispatchSync($to,$acc);
	}
}