<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;

use App\Models\{ProviderOauth,Site,User};
use App\Jobs\AccountingAccountSync as Job;

/**
 * Synchronise Customers with Accounts
 */
class AccountingAccountSync extends Command
{
	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'accounting:account:sync'
		.' {siteid : Site ID}'
		.' {provider : Provider Name}'
		.' {user : User Email}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Synchronise accounts with accounting system';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 */
	public function handle()
	{
		$site = Site::findOrFail($this->argument('siteid'));
		Config::set('site',$site);

		$uo = User::where('email',$this->argument('user'))->singleOrFail();

		$so = ProviderOauth::where('name',$this->argument('provider'))->singleOrFail();
		if (! ($to=$so->token($uo)))
			abort(500,sprintf('Unknown Tokens for [%s]',$uo->email));

		Job::dispatchSync($to);
	}
}