<?php

namespace App\Console\Commands;

use GuzzleHttp\Exception\ConnectException;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;
use Intuit\Exceptions\ConnectionIssueException;

use App\Models\{ProviderOauth,Site,User};

class AccountingInvoiceGet extends Command
{
	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'accounting:invoice:get'
		.' {siteid : Site ID}'
		.' {provider : Provider Name}'
		.' {user : User Email}'
		.' {id : Invoice ID}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Get an invoice from the accounting provider';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 */
	public function handle()
	{
		$site = Site::findOrFail($this->argument('siteid'));
		Config::set('site',$site);

		$uo = User::where('email',$this->argument('user'))->singleOrFail();

		$so = ProviderOauth::where('name',$this->argument('provider'))->singleOrFail();
		if (! ($to=$so->token($uo)))
			abort(500,sprintf('Unknown Tokens for [%s]',$uo->email));

		try {
			$api = $to->API();
			dump($api->getInvoiceQuery($this->argument('id')));

		} catch (ConnectException|ConnectionIssueException $e) {
			$this->error($e->getMessage());

			return Command::FAILURE;
		}
	}
}